@@ -1,9 +1,7 @@
 cleanupPasswordFile <- function(appDir) {
 
-  # normalize appDir path and ensure it exists
-  appDir <- normalizePath(appDir, mustWork = FALSE)
-  if (!file.exists(appDir) || !file.info(appDir)$isdir)
-    stop(appDir, " is not a valid directory", call. = FALSE)
+  check_directory(appDir)
+  appDir <- normalizePath(appDir)
 
   # get data dir from appDir
   dataDir <- file.path(appDir, "shinyapps")
@@ -36,10 +34,7 @@ cleanupPasswordFile <- function(appDir) {
 #' @param appDir Directory containing application. Defaults to
 #'   current working directory.
 #' @param appName Name of application.
-#' @param account Account name. If a single account is registered on the
-#'   system then this parameter can be omitted.
-#' @param server Server name. Required only if you use the same account name on
-#'   multiple servers.
+#' @inheritParams deployApp
 #' @param sendEmail Send an email letting the user know the application
 #'   has been shared with them.
 #' @param emailMessage Optional character vector of length 1 containing a
@@ -52,8 +47,8 @@ addAuthorizedUser <- function(email, appDir = getwd(), appName = NULL,
                               account = NULL, server = NULL, sendEmail = NULL,
                               emailMessage = NULL) {
 
-  # resolve account
-  accountDetails <- accountInfo(resolveAccount(account, server), server)
+  accountDetails <- accountInfo(account, server)
+  checkShinyappsServer(accountDetails$server)
 
   # resolve application
   if (is.null(appName))
@@ -79,18 +74,15 @@ addAuthorizedUser <- function(email, appDir = getwd(), appName = NULL,
 #' @param appDir Directory containing application. Defaults to
 #' current working directory.
 #' @param appName Name of application.
-#' @param account Account name. If a single account is registered on the
-#'   system then this parameter can be omitted.
-#' @param server Server name. Required only if you use the same account name on
-#'   multiple servers.
+#' @inheritParams deployApp
 #' @seealso [addAuthorizedUser()] and [showUsers()]
 #' @note This function works only for ShinyApps servers.
 #' @export
 removeAuthorizedUser <- function(user, appDir = getwd(), appName = NULL,
                                  account = NULL, server = NULL) {
 
-  # resolve account
-  accountDetails <- accountInfo(resolveAccount(account, server), server)
+  accountDetails <- accountInfo(account, server)
+  checkShinyappsServer(accountDetails$server)
 
   # resolve application
   if (is.null(appName))
@@ -133,22 +125,15 @@ removeAuthorizedUser <- function(user, appDir = getwd(), appName = NULL,
 #' @param appDir Directory containing application. Defaults to
 #'   current working directory.
 #' @param appName Name of application.
-#' @param account Account name. If a single account is registered on the
-#'   system then this parameter can be omitted.
-#' @param server Server name. Required only if you use the same account name on
-#'   multiple servers.
+#' @inheritParams deployApp
 #' @seealso [addAuthorizedUser()] and [showInvited()]
 #' @note This function works only for ShinyApps servers.
 #' @export
 showUsers <- function(appDir = getwd(), appName = NULL, account = NULL,
                       server = NULL) {
 
-  # resolve account
-  accountDetails <- accountInfo(resolveAccount(account, server), server)
-
-  if (!isCloudServer(accountDetails$server)) {
-    stop("This method only works for ShinyApps or posit.cloud servers.")
-  }
+  accountDetails <- accountInfo(account, server)
+  checkShinyappsServer(accountDetails$server)
 
   # resolve application
   if (is.null(appName))
@@ -183,18 +168,15 @@ showUsers <- function(appDir = getwd(), appName = NULL, account = NULL,
 #' @param appDir Directory containing application. Defaults to
 #'   current working directory.
 #' @param appName Name of application.
-#' @param account Account name. If a single account is registered on the
-#'   system then this parameter can be omitted.
-#' @param server Server name. Required only if you use the same account name on
-#'   multiple servers.
+#' @inheritParams deployApp
 #' @seealso [addAuthorizedUser()] and [showUsers()]
 #' @note This function works only for ShinyApps servers.
 #' @export
 showInvited <- function(appDir = getwd(), appName = NULL, account = NULL,
                         server = NULL) {
 
-  # resolve account
-  accountDetails <- accountInfo(resolveAccount(account, server), server)
+  accountDetails <- accountInfo(account, server)
+  checkShinyappsServer(accountDetails$server)
 
   # resolve application
   if (is.null(appName))
@@ -229,10 +211,7 @@ showInvited <- function(appDir = getwd(), appName = NULL, account = NULL,
 #' @param appDir Directory containing application. Defaults to
 #'   current working directory.
 #' @param appName Name of application.
-#' @param account Account name. If a single account is registered on the
-#'   system then this parameter can be omitted.
-#' @param server Server name. Required only if you use the same account name on
-#'   multiple servers.
+#' @inheritParams deployApp
 #' @seealso [showInvited()]
 #' @note This function works only for ShinyApps servers.
 #' @export
@@ -240,8 +219,8 @@ resendInvitation <- function(invite, regenerate = FALSE,
                              appDir = getwd(), appName = NULL,
                              account = NULL, server = NULL) {
 
-  # resolve account
-  accountDetails <- accountInfo(resolveAccount(account, server), server)
+  accountDetails <- accountInfo(account, server)
+  checkShinyappsServer(accountDetails$server)
 
   # get invitations
   invited <- showInvited(appDir, appName, account, server)
@@ -300,15 +279,9 @@ validateEmail <- function(email) {
 }
 
 getPasswordFile <- function(appDir) {
-  if (!isStringParam(appDir))
-    stop(stringParamErrorMessage("appDir"))
+  check_directory(appDir)
 
-  # normalize appDir path and ensure it exists
-  appDir <- normalizePath(appDir, mustWork = FALSE)
-  if (!file.exists(appDir) || !file.info(appDir)$isdir)
-    stop(appDir, " is not a valid directory", call. = FALSE)
-
-  file.path(appDir, "shinyapps", "passwords.txt")
+  file.path(normalizePath(appDir), "shinyapps", "passwords.txt")
 }
 
 readPasswordFile <- function(path) {
@@ -331,7 +304,7 @@ writePasswordFile <- function(path, passwords) {
 
   # open and file
   f <- file(path, open = "w")
-  on.exit(close(f), add = TRUE)
+  defer(close(f))
 
   # write passwords
   apply(passwords, 1, function(r) {
